@@ -6,11 +6,11 @@ or in the configuration file.
 """
 import click
 
+from telliot_core.cli.commands.account import account
 from telliot_core.cli.commands.catalog import catalog
 from telliot_core.cli.commands.config import config
 from telliot_core.cli.commands.query import query
 from telliot_core.cli.commands.read import read
-from telliot_core.cli.commands.staker import staker
 from telliot_core.utils.versions import show_telliot_versions
 
 
@@ -44,7 +44,7 @@ main.add_command(config)
 main.add_command(read)
 main.add_command(query)
 main.add_command(catalog)
-main.add_command(staker)
+main.add_command(account)
 
 if __name__ == "__main__":
     main()
