@@ -103,6 +103,13 @@ default_endpoint_list = [
         url="https://rpc-mainnet.matic.network",
         explorer="https://matic.network",
     ),
+    RPCEndpoint(
+        chain_id=80001,
+        provider="Matic",
+        network="mumbai",
+        url="https://rpc-mumbai.maticvigil.com",
+        explorer="https://mumbai.polygonscan.com/",
+    ),
 ]
 
 
@@ -119,6 +126,27 @@ class EndpointList(ConfigOptions):
 
         return None
 
+    def find(
+        self,
+        *,
+        chain_id: Optional[int] = None,
+        provider: Optional[str] = None,
+    ) -> list[RPCEndpoint]:
+
+        result = []
+        for ep in self.endpoints:
+
+            if chain_id is not None:
+                if chain_id != ep.chain_id:
+                    continue
+            if provider is not None:
+                if provider != ep.provider:
+                    continue
+
+            result.append(ep)
+
+        return result
+
 
 if __name__ == "__main__":
     cf = ConfigFile(name="endpoints", config_type=EndpointList, config_format="yaml")
